@@ -218,6 +218,8 @@ class anim_text:
 
         self.obj = ob
 
+        ob.name = name + '_text'
+
         self.obj.parent = parent
         self.name = name
 
@@ -227,23 +229,11 @@ class anim_text:
         fixed_data = frame_interper(all_frames)
 
         if not(if_str):
-            def update(self):
+            def recalculate_text(scene):
                 text = ob
                 cur_frame = bpy.context.scene.frame_current
                 
                 text.data.body = ('{0:.'+str(fix_place)+'f}').format(fixed_data[cur_frame-1]) + ' ' + label
                     
-        else:
-            def update(self):
-                text = ob
-                cur_frame = bpy.context.scene.frame_current
-                
-                text.data.body = ('{0:.'+str(fix_place)+'f}').format(fixed_data[cur_frame-1]) + ' ' + label
 
-        def register():
-            bpy.app.handlers.frame_change_post.append(update)
-
-        def unregister():
-            bpy.app.handlers.frame_change_post.remove(update)
-
-        register()
\ No newline at end of file
+            bpy.app.handlers.frame_change_pre.append(recalculate_text)
\ No newline at end of file
